@@ -111,6 +111,9 @@ class OxenStorage(StorageBackend):
                                 print(f"🔄 Updating namespace from {self.namespace} to {actual_namespace}")
                                 self.namespace = actual_namespace
 
+                        # Transform hub.oxen.ai URL to public oxen.ai URL for display
+                        api_url = response_data["repository"]["url"]
+                        public_url = api_url.replace("https://hub.oxen.ai/", "https://oxen.ai/")
                         print(f"✅ Created Oxen repository: {self.namespace}/{repo_name}")
 
                         # Wait a moment for the repository to be fully created
@@ -324,29 +327,25 @@ class OxenStorage(StorageBackend):
                         f.write(f"  Timestamp: {result.timestamp}\n")
                         f.write("\n")
 
-                # Upload files
-                files_to_upload = [
-                    (json_file, "data/findings.json"),
-                    (csv_file, "data/findings.csv"),
-                    (text_file, "reports/findings.txt")
-                ]
-
-                # Note: Oxen doesn't support direct file uploads via REST API
-                # Instead, we create the repository as a permanent record of the analysis
-                print(f"📊 Analysis complete: {len(results)} findings detected")
-                print(f"📁 Repository created: https://hub.oxen.ai/{self.namespace}/{self.current_repo}")
-                print(f"💡 Oxen uses workspace-based data management - repository serves as permanent analysis record")
+                # Try to populate the repository with data
+                success = self._populate_repository_with_data(results, temp_path)
+                if success:
+                    print(f"📊 Analysis complete: {len(results)} findings detected - data uploaded to repository")
+                else:
+                    print(f"📊 Analysis complete: {len(results)} findings detected - repository created (data upload failed)")
+                print(f"📁 Repository created: https://oxen.ai/{self.namespace}/{self.current_repo}")
+                print(f"💡 Oxen uses workspace-based data management - repository contains analysis results")
 
                 # Create a local summary file for reference
                 summary_path = temp_path / "analysis_summary.txt"
                 with open(summary_path, 'w') as f:
                     f.write(f"Pantsonfire Analysis Summary\n")
-                    f.write(f"Repository: https://hub.oxen.ai/{self.namespace}/{self.current_repo}\n")
+                    f.write(f"Repository: https://oxen.ai/{self.namespace}/{self.current_repo}\n")
                     f.write(f"Timestamp: {datetime.now().isoformat()}\n")
                     f.write(f"Total Findings: {len(results)}\n")
                     f.write(f"Oxen Data Management: Workspace-based (not traditional Git)\n")
 
-                print(f"✅ Analysis repository created successfully at: https://hub.oxen.ai/{self.namespace}/{self.current_repo}")
+                print(f"✅ Analysis repository created successfully at: https://oxen.ai/{self.namespace}/{self.current_repo}")
 
                 # Always return True since repository was created successfully
                 return True
@@ -355,6 +354,90 @@ class OxenStorage(StorageBackend):
             print(f"❌ Error storing findings: {e}")
             return False
 
+    def _populate_repository_with_data(self, results: List[CheckResult], temp_path: Path) -> bool:
+        """
+        Populate the repository with analysis data using Oxen's workspace system.
+
+        Args:
+            results: Analysis results to store
+            temp_path: Path to temporary files
+
+        Returns:
+            True if data was successfully added to the repository
+        """
+        try:
+            # Step 1: Create a workspace for this repository
+            workspace_name = f"analysis_{datetime.now().strftime('%Y%m%d_%H%M%S')}"
+
+            # Create workspace
+            workspace_data = {"name": workspace_name}
+            response = self.session.post(
+                f"{self.base_url}/api/repos/{self.namespace}/{self.current_repo}/workspaces",
+                json=workspace_data
+            )
+
+            if response.status_code not in [200, 201]:
+                print(f"⚠️  Could not create workspace: {response.status_code} - {response.text}")
+                return False
+
+            workspace_info = response.json()
+            print(f"✅ Created workspace: {workspace_name}")
+
+            # Step 2: Add data to the workspace
+            # Convert results to JSON for upload
+            results_data = [result.model_dump() for result in results]
+
+            # Create a dataframe with the results
+            dataframe_data = {
+                "name": "findings",
+                "data": results_data,
+                "schema": {
+                    "fields": [
+                        {"name": "blog_source", "dtype": "str"},
+                        {"name": "truth_source", "dtype": "str"},
+                        {"name": "discrepancy", "dtype": "str"},
+                        {"name": "confidence", "dtype": "float"},
+                        {"name": "evidence", "dtype": "str"},
+                        {"name": "chunk_index", "dtype": "int"},
+                        {"name": "timestamp", "dtype": "datetime"}
+                    ]
+                }
+            }
+
+            # Add dataframe to workspace
+            response = self.session.post(
+                f"{self.base_url}/api/repos/{self.namespace}/{self.current_repo}/workspaces/{workspace_name}/dataframes",
+                json=dataframe_data
+            )
+
+            if response.status_code not in [200, 201]:
+                print(f"⚠️  Could not add dataframe: {response.status_code} - {response.text}")
+                return False
+
+            print(f"✅ Added findings dataframe to workspace")
+
+            # Step 3: Commit the workspace to create a permanent record
+            commit_data = {
+                "message": f"Pantsonfire analysis: {len(results)} findings detected",
+                "author": "pantsonfire"
+            }
+
+            response = self.session.post(
+                f"{self.base_url}/api/repos/{self.namespace}/{self.current_repo}/workspaces/{workspace_name}/commit",
+                json=commit_data
+            )
+
+            if response.status_code in [200, 201]:
+                print(f"✅ Committed analysis data to repository")
+                return True
+            else:
+                print(f"⚠️  Could not commit workspace: {response.status_code} - {response.text}")
+                return False
+
+        except Exception as e:
+            print(f"⚠️  Error populating repository with data: {e}")
+            return False
+
     def get_results(self, limit: Optional[int] = None) -> List[CheckResult]:
         """
         Retrieve stored results (implements StorageBackend protocol)
